==> owncloud-10.0.10.zip: owncloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Datafællesskabsdeling",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "File is already shared with %s" : "Filen er allerede delt med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket.",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Du modtog \"/%3$s\" som en ekstern deling fra %1$s (på vejne af %2$s)",
    "You received \"/%3$s\" as a remote share from %1$s" : "Du modtog \"/%3$s\" som en ekstern deling fra %1$s",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med mig gennem min #ownCloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med mig gennem min #ownCloud Federated Cloud ID",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åben dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it:" : "Del:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via ownCloud" : "Del med mig gennem ownCloud",
    "HTML Code:" : "HTMLkode:",
    "Add to your ownCloud" : "Tilføj til din ownCload"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/federatedfilesharing/l10n/da.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Datafællesskabsdeling",
    "Add to your ownCloud" : "Tilføj til din ownCload",
    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
    "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
    "File is already shared with %s" : "Filen er allerede delt med %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket.",
    "Accept" : "Acceptér",
    "Decline" : "Afvis",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "Del med mig gennem min #ownCloud Federated Cloud ID, se %s",
    "Share with me through my #ownCloud Federated Cloud ID" : "Del med mig gennem min #ownCloud Federated Cloud ID",
    "Federated Cloud Sharing" : "Sammensluttet Cloud deling",
    "Open documentation" : "Åben dokumentation",
    "Allow users on this server to send shares to other servers" : "Tillad brugere på denne server, at sende delinger til andre servere",
    "Allow users on this server to receive shares from other servers" : "Tillad brugere på denne server, at modtage delinger fra andre servere",
    "Federated Cloud" : "Federated Cloud",
    "Your Federated Cloud ID:" : "Din Federated Cloud ID:",
    "Share it:" : "Del:",
    "Add to your website" : "Tilføj til dit websted",
    "Share with me via ownCloud" : "Del med mig gennem ownCloud",
    "HTML Code:" : "HTMLkode:"
},
"nplurals=2; plural=(n != 1);");
